@@ -73,16 +73,14 @@ class MysqlService(DBService):
     def transaction(self, sql_list):
         s = self.server.connection()
         with s.cursor() as cursor:
-            s.begin()
-            count = [cursor.execute(sql) for sql in sql_list]
-            if set(count) == {1}:
+            try:
+                s.begin()
+                [cursor.execute(sql) for sql in sql_list]
                 s.commit()
-                result = True
-            else:
+                return True
+            except Exception:
                 s.rollback()
-                result = False
-            # print("\n\nexecute %s  %s\n\n" % (sql, count))
-            return result
+                return False
 
     @classmethod
     def join_sql_from_map(cls, insert_table, args_map, db_name=None):
@@ -213,13 +211,6 @@ class MysqlService(DBService):
 
 
 class RedisService(DBService):
-    _instance = None
-
-    def __new__(cls, *args, **kwargs):
-        if not cls._instance:
-            cls._instance = super().__new__(cls)
-        return cls._instance
-
     def __init__(self, redis_url):
         self.redis = import_module("redis")
         pool = self.redis.ConnectionPool.from_url(
@@ -289,13 +280,6 @@ class PgsqlService(DBService):
 
 
 class AsyncRedisService(DBService):
-    _instance = None
-
-    def __new__(cls, *args, **kwargs):
-        if not cls._instance:
-            cls._instance = super().__new__(cls)
-        return cls._instance
-
     def __init__(self, redis_url):
         self.redis = import_module('redis.asyncio')
         self.server = self.redis.from_url(
@@ -438,10 +422,10 @@ class AsyncMysqlService(DBService):
         async with self.pool.acquire() as conn:
             async with conn.cursor() as cur:
                 try:
-                    await cur.execute("START TRANSACTION")
-                    for query, params in queries:
-                        await cur.execute(query, params)
-                    await cur.execute("COMMIT")
+                    await conn.begin()
+                    for query in queries:
+                        await cur.execute(query)
+                    await conn.commit()
                 except Exception as e:
                     await cur.execute("ROLLBACK")
                     raise e
